==> msgraph-sdk-android-1.2.0-sources.jar: com/microsoft/graph/extensions/MultiValueLegacyExtendedPropertyCollectionPage.java <==
// ------------------------------------------------------------------------------
// Copyright (c) Microsoft Corporation.  All Rights Reserved.  Licensed under the MIT License.  See License in the project root for license information.
// ------------------------------------------------------------------------------

package com.microsoft.graph.extensions;

import com.microsoft.graph.concurrency.*;
import com.microsoft.graph.core.*;
import com.microsoft.graph.extensions.*;
import com.microsoft.graph.http.*;
import com.microsoft.graph.generated.*;
import com.microsoft.graph.options.*;
import com.microsoft.graph.serializer.*;

import java.util.Arrays;
import java.util.List;

// This file is available for extending, afterwards please submit a pull request.

/**
 * The class for the Multi Value Legacy Extended Property Collection Page.
 */
public class MultiValueLegacyExtendedPropertyCollectionPage extends BaseMultiValueLegacyExtendedPropertyCollectionPage implements IMultiValueLegacyExtendedPropertyCollectionPage {

    /**
     * A collection page for Post.
     *
     * @param response The serialized BaseMultiValueLegacyExtendedPropertyCollectionResponse from the service
     * @param builder The request builder for the next collection page
     */
    public MultiValueLegacyExtendedPropertyCollectionPage(final BaseMultiValueLegacyExtendedPropertyCollectionResponse response, final IMultiValueLegacyExtendedPropertyCollectionRequestBuilder builder) {
        super(response, builder);
    }
}

==> msgraph-sdk-android-1.7.0-sources.jar: com/microsoft/graph/extensions/MultiValueLegacyExtendedPropertyCollectionPage.java <==
// ------------------------------------------------------------------------------
// Copyright (c) Microsoft Corporation.  All Rights Reserved.  Licensed under the MIT License.  See License in the project root for license information.
// ------------------------------------------------------------------------------

package com.microsoft.graph.extensions;

import com.microsoft.graph.concurrency.*;
import com.microsoft.graph.core.*;
import com.microsoft.graph.extensions.*;
import com.microsoft.graph.http.*;
import com.microsoft.graph.generated.*;
import com.microsoft.graph.options.*;
import com.microsoft.graph.serializer.*;

import java.util.Arrays;
import java.util.EnumSet;

// This file is available for extending, afterwards please submit a pull request.

/**
 * The class for the Multi Value Legacy Extended Property Collection Page.
 */
public class MultiValueLegacyExtendedPropertyCollectionPage extends BaseMultiValueLegacyExtendedPropertyCollectionPage implements IMultiValueLegacyExtendedPropertyCollectionPage {

    /**
     * A collection page for Post.
     *
     * @param response The serialized BaseMultiValueLegacyExtendedPropertyCollectionResponse from the service
     * @param builder The request builder for the next collection page
     */
    public MultiValueLegacyExtendedPropertyCollectionPage(final BaseMultiValueLegacyExtendedPropertyCollectionResponse response, final IMultiValueLegacyExtendedPropertyCollectionRequestBuilder builder) {
        super(response, builder);
    }
}
